@@ -15,7 +15,7 @@ from gi.repository import GLib, GdkPixbuf, Gio, Gst
 import re
 
 from lollypop.tagreader import TagReader
-from lollypop.define import App, ArtSize
+from lollypop.define import App, ArtSize, ArtHelperEffect
 from lollypop.objects import Album
 from lollypop.logger import Logger
 from lollypop.utils import escape, is_readonly
@@ -77,12 +77,16 @@ class AlbumArt:
         """
         if album.id is None:
             return None
-        self.__update_album_uri(album)
         try:
             filename = self.get_album_cache_name(album) + ".jpg"
+            self.__update_album_uri(album)
+            if album.mtime == 0:
+                store_path = self._WEB_PATH + "/" + filename
+            else:
+                store_path = self._STORE_PATH + "/" + filename
             uris = [
-                # Used when album.uri is readonly
-                GLib.filename_to_uri(self._STORE_PATH + "/" + filename),
+                # Used when album.uri is readonly or for Web
+                GLib.filename_to_uri(store_path),
                 # Default favorite artwork
                 album.uri + "/" + self.__favorite,
                 # Used when having muliple albums in same folder
@@ -141,14 +145,15 @@ class AlbumArt:
             print("AlbumArt::get_album_artworks()", e)
         return uris
 
-    def get_album_artwork(self, album, width, height, scale, cache=True):
+    def get_album_artwork(self, album, width, height, scale,
+                          effect=ArtHelperEffect.SAVE):
         """
             Return a cairo surface for album_id, covers are cached as jpg.
             @param album as Album
             @param width as int
             @param height as int
             @param scale factor as int
-            @param cache as bool
+            @param effect as ArtHelperEffect
             @return cairo surface
             @thread safe
         """
@@ -182,7 +187,9 @@ class AlbumArt:
                             height,
                             True,
                             None)
-                        pixbuf = self._preserve_ratio(pixbuf, width, height)
+                        # Pixbuf will be resized, cropping not needed
+                        if not effect & ArtHelperEffect.RESIZE:
+                            pixbuf = self._crop_pixbuf(pixbuf)
                         stream.close()
                 # Use tags artwork
                 if pixbuf is None and album.tracks:
@@ -208,11 +215,13 @@ class AlbumArt:
                             True,
                             None)
                         stream.close()
-                        pixbuf = self._preserve_ratio(pixbuf, width, height)
+                        # Pixbuf will be resized, cropping not needed
+                        if not effect & ArtHelperEffect.RESIZE:
+                            pixbuf = self._crop_pixbuf(pixbuf)
                 # Search on the web
                 if pixbuf is None:
                     self.cache_album_art(album.id)
-                elif cache:
+                elif effect & ArtHelperEffect.SAVE:
                     pixbuf.savev(cache_path_jpg, "jpeg", ["quality"],
                                  [str(App().settings.get_value(
                                      "cover-quality").get_int32())])
@@ -238,7 +247,10 @@ class AlbumArt:
                 helper = TaskHelper()
                 helper.run(self.__save_artwork_to_tags, data, album)
 
-            store_path = self._STORE_PATH + "/" + filename
+            if album.mtime == 0:
+                store_path = self._WEB_PATH + "/" + filename
+            else:
+                store_path = self._STORE_PATH + "/" + filename
             if album.uri == "" or is_readonly(album.uri):
                 arturi = GLib.filename_to_uri(store_path)
             # Many albums with same path, suffix with artist_album name
@@ -320,7 +332,7 @@ class AlbumArt:
             @param height as int
         """
         pixbuf = None
-        if uri.startswith("http:") or uri.startswith("https:"):
+        if uri.startswith("web:"):
             return
         try:
             tag_reader = TagReader()
@@ -364,13 +376,15 @@ class AlbumArt:
             Check if album uri exists, update if not
             @param album as Album
         """
+        if not album.uri:
+            return
         d = Gio.File.new_for_uri(album.uri)
         if not d.query_exists():
             if album.tracks:
                 track_uri = album.tracks[0].uri
                 f = Gio.File.new_for_uri(track_uri)
                 p = f.get_parent()
-                parent_uri = "/" if p is None else p.get_uri()
+                parent_uri = "" if p is None else p.get_uri()
                 album.set_uri(parent_uri)
 
     def __save_artwork_to_tags(self, data, album):
