@@ -34,6 +34,8 @@ class ViewsContainer:
             Show lyrics for track
             @pram track as Track
         """
+        if track is None and App().player.current_track.id is None:
+            return
         from lollypop.view_lyrics import LyricsView
         current = self._stack.get_visible_child()
         view = LyricsView()
@@ -46,7 +48,7 @@ class ViewsContainer:
     def show_view(self, item_id, data=None, switch=True):
         """
             Show view for item id
-            @param item_ids as int
+            @param item_id as int
             @param data as object
             @param switch as bool
         """
@@ -55,10 +57,11 @@ class ViewsContainer:
                        Type.LOVED,
                        Type.RECENTS,
                        Type.NEVER,
-                       Type.RANDOMS]:
+                       Type.RANDOMS,
+                       Type.WEB]:
             view = self._get_view_albums([item_id], [])
         elif item_id == Type.SEARCH:
-            view = self._get_view_search()
+            view = self.get_view_search(data)
         elif item_id == Type.INFO:
             view = self._get_view_info()
         elif item_id == Type.GENRES:
@@ -75,8 +78,6 @@ class ViewsContainer:
                 view = self._get_view_albums_years(data)
         elif item_id == Type.PLAYLISTS:
             view = self._get_view_playlists([] if data is None else data)
-        elif item_id == Type.COMPILATIONS:
-            view = self._get_view_albums([], [item_id])
         elif item_id == Type.RADIOS:
             view = self._get_view_radios()
         elif item_id == Type.EQUALIZER:
@@ -89,15 +90,11 @@ class ViewsContainer:
                          Type.SETTINGS_WEB]:
             view = self._get_view_settings(item_id)
         elif Type.DEVICES - 999 < item_id < Type.DEVICES:
-            from lollypop.view_device import DeviceView
-            # Search for an existing view
-            view = None
-            for child in self._stack.get_children():
-                if isinstance(child, DeviceView):
-                    view = child
-                    break
-            if view is None:
-                view = self._get_view_device(item_id)
+            view = self._get_view_device(item_id)
+        elif item_id == Type.ALL:
+            view = self._get_view_albums([item_id], [])
+        elif item_id == Type.COMPILATIONS:
+            view = self._get_view_albums([], [item_id])
         else:
             view = self._get_view_artists([], [item_id])
         view.show()
@@ -112,7 +109,7 @@ class ViewsContainer:
         """
         if App().player.queue and not view_type & ViewType.FULLSCREEN:
             from lollypop.view_queue import QueueView
-            view = QueueView()
+            view = QueueView(view_type)
             view.populate()
         elif App().player.playlist_ids:
             from lollypop.view_playlists import PlaylistsView
@@ -127,6 +124,75 @@ class ViewsContainer:
         view.show()
         return view
 
+    def get_view_search(self, search=""):
+        """
+            Get view for search
+            @param search as str
+            @return SearchView
+        """
+        from lollypop.view_search import SearchView
+        # Search view in children
+        for child in self._stack.get_children():
+            if isinstance(child, SearchView):
+                child.set_search(search)
+                return child
+        view = SearchView()
+        view.set_margin_top(MARGIN_SMALL)
+        view.set_margin_start(MARGIN_SMALL)
+        view.set_search(search)
+        view.show()
+        return view
+
+    def get_view_album_ids(self, genre_ids, artist_ids):
+        """
+            Get albums view for genres/artists
+            @param genre ids as [int]
+            @param artist_ids as [int]
+            @return [int]
+        """
+        items = []
+        is_compilation = artist_ids and artist_ids[0] == Type.COMPILATIONS
+        if genre_ids and genre_ids[0] == Type.ALL:
+            if is_compilation or\
+                    App().settings.get_value(
+                        "show-compilations-in-album-view"):
+                items = App().albums.get_compilation_ids([])
+            if not is_compilation:
+                items += App().albums.get_ids([], [])
+        elif genre_ids and genre_ids[0] == Type.POPULARS:
+            items = App().albums.get_rated()
+            count = 100 - len(items)
+            for album in App().albums.get_populars(count):
+                if album not in items:
+                    items.append(album)
+        elif genre_ids and genre_ids[0] == Type.LOVED:
+            items = App().albums.get_loved_albums()
+        elif genre_ids and genre_ids[0] == Type.RECENTS:
+            items = App().albums.get_recents()
+        elif genre_ids and genre_ids[0] == Type.NEVER:
+            items = App().albums.get_never_listened_to()
+        elif genre_ids and genre_ids[0] == Type.RANDOMS:
+            items = App().albums.get_randoms()
+        else:
+            if is_compilation or\
+                    App().settings.get_value(
+                        "show-compilations-in-album-view"):
+                items = App().albums.get_compilation_ids(genre_ids)
+            if not is_compilation:
+                items += App().albums.get_ids([], genre_ids)
+        return items
+
+    def show_artist_view(self, artist_ids):
+        """
+            Go to artist view
+            @param artist_ids as [int]
+        """
+        if App().settings.get_value("show-sidebar") and\
+                not App().window.is_adaptive:
+            App().window.container.show_artists_albums(artist_ids)
+        else:
+            App().window.container.show_view(artist_ids[0])
+
 ##############
 # PROTECTED  #
 ##############
@@ -346,38 +412,9 @@ class ViewsContainer:
             @param is compilation as bool
         """
         def load():
-            items = []
-            is_compilation = artist_ids and artist_ids[0] == Type.COMPILATIONS
-            if genre_ids and genre_ids[0] == Type.ALL:
-                if is_compilation or\
-                        App().settings.get_value(
-                            "show-compilations-in-album-view"):
-                    items = App().albums.get_compilation_ids([])
-                if not is_compilation:
-                    items += App().albums.get_ids([], [])
-            elif genre_ids and genre_ids[0] == Type.POPULARS:
-                items = App().albums.get_rated()
-                count = 100 - len(items)
-                for album in App().albums.get_populars(count):
-                    if album not in items:
-                        items.append(album)
-            elif genre_ids and genre_ids[0] == Type.LOVED:
-                items = App().albums.get_loved_albums()
-            elif genre_ids and genre_ids[0] == Type.RECENTS:
-                items = App().albums.get_recents()
-            elif genre_ids and genre_ids[0] == Type.NEVER:
-                items = App().albums.get_never_listened_to()
-            elif genre_ids and genre_ids[0] == Type.RANDOMS:
-                items = App().albums.get_randoms()
-            else:
-                if is_compilation or\
-                        App().settings.get_value(
-                            "show-compilations-in-album-view"):
-                    items = App().albums.get_compilation_ids(genre_ids)
-                if not is_compilation:
-                    items += App().albums.get_ids([], genre_ids)
+            album_ids = self.get_view_album_ids(genre_ids, artist_ids)
             return [Album(album_id, genre_ids, artist_ids)
-                    for album_id in items]
+                    for album_id in album_ids]
 
         if App().window.is_adaptive:
             from lollypop.view_albums_list import AlbumsListView
@@ -417,20 +454,6 @@ class ViewsContainer:
         view.populate()
         view.set_margin_top(MARGIN_SMALL)
         view.set_margin_start(MARGIN_SMALL)
-        view.set_margin_end(MARGIN_SMALL)
-        view.show()
-        return view
-
-    def _get_view_search(self):
-        """
-            Get view for search
-            @return SearchView
-        """
-        from lollypop.view_search import SearchView
-        view = SearchView()
-        view.set_margin_top(MARGIN_SMALL)
-        view.set_margin_start(MARGIN_SMALL)
-        view.set_margin_end(MARGIN_SMALL)
         view.show()
         return view
 
