@@ -107,7 +107,7 @@ class ArtistsDatabase:
             v = result.fetchone()
             if v is not None:
                 return v[0]
-            return _("Unknown")
+            return None
 
     def get_albums(self, artist_ids):
         """
@@ -161,6 +161,7 @@ class ArtistsDatabase:
                     "SELECT DISTINCT %s FROM artists, albums, album_artists\
                                   WHERE album_artists.artist_id=artists.rowid\
                                   AND album_artists.album_id=albums.rowid\
+                                  AND albums.mtime!=0\
                                   ORDER BY artists.sortname\
                                   COLLATE NOCASE COLLATE LOCALIZED" % select)
             else:
@@ -169,6 +170,7 @@ class ArtistsDatabase:
                            FROM artists, albums, album_genres, album_artists\
                            WHERE artists.rowid=album_artists.artist_id\
                            AND albums.rowid=album_artists.album_id\
+                           AND albums.mtime!=0\
                            AND album_genres.album_id=albums.rowid AND ("
                 for genre_id in genre_ids:
                     request += "album_genres.genre_id=? OR "
@@ -192,7 +194,10 @@ class ArtistsDatabase:
             if not genre_ids or genre_ids[0] == Type.ALL:
                 # Only artist that really have an album
                 result = sql.execute(
-                    "SELECT DISTINCT %s FROM artists\
+                    "SELECT DISTINCT %s FROM artists, album_artists, albums\
+                                  WHERE artists.rowid=album_artists.artist_id\
+                                  AND albums.rowid=album_artists.album_id\
+                                  AND albums.mtime!=0\
                                   ORDER BY artists.sortname\
                                   COLLATE NOCASE COLLATE LOCALIZED" % select)
             else:
@@ -201,6 +206,7 @@ class ArtistsDatabase:
                            FROM artists, tracks, track_genres, track_artists\
                            WHERE artists.rowid=track_artists.artist_id\
                            AND tracks.rowid=track_artists.track_id\
+                           AND tracks.mtime!=0\
                            AND track_genres.track_id=tracks.rowid AND ("
                 for genre_id in genre_ids:
                     request += "track_genres.genre_id=? OR "
@@ -224,6 +230,7 @@ class ArtistsDatabase:
                                   FROM artists, albums, album_artists\
                                   WHERE album_artists.artist_id=artists.rowid\
                                   AND album_artists.album_id=albums.rowid\
+                                  AND albums.mtime!=0\
                                   ORDER BY artists.sortname\
                                   COLLATE NOCASE COLLATE LOCALIZED")
             else:
@@ -231,6 +238,7 @@ class ArtistsDatabase:
                 request = "SELECT DISTINCT artists.rowid\
                            FROM artists, albums, album_genres, album_artists\
                            WHERE artists.rowid=album_artists.artist_id\
+                           AND albums.mtime!=0\
                            AND albums.rowid=album_artists.album_id\
                            AND album_genres.album_id=albums.rowid AND ("
                 for genre_id in genre_ids:
@@ -256,8 +264,8 @@ class ArtistsDatabase:
     def search(self, searched):
         """
             Search for artists looking like string
-            @param string
-            @return Array of id as int
+            @param searched as str
+            @return [int]
         """
         no_accents = noaccents(searched)
         with SqlCursor(App().db) as sql:
@@ -265,10 +273,12 @@ class ArtistsDatabase:
             for filter in [(no_accents + "%",),
                            ("%" + no_accents,),
                            ("%" + no_accents + "%",)]:
-                result = sql.execute("SELECT artists.rowid\
-                                      FROM artists\
-                                      WHERE noaccents(name) LIKE ? LIMIT 25",
-                                     filter)
+                request = "SELECT artists.rowid\
+                           FROM artists, albums, album_artists\
+                           WHERE album_artists.artist_id=artists.rowid\
+                           AND album_artists.album_id=albums.rowid\
+                           AND noaccents(artists.name) LIKE ? LIMIT 25"
+                result = sql.execute(request, filter)
                 items += list(itertools.chain(*result))
             return items
 
@@ -287,28 +297,13 @@ class ArtistsDatabase:
                 return v[0]
             return 0
 
-    def clean(self, artist_id):
+    def clean(self):
         """
-            Clean database for artist id
-            @param artist id as int
-            @return cleaned as bool
-            @warning commit needed
+            Clean artists
         """
         with SqlCursor(App().db, True) as sql:
-            cleaned = False
-            result = sql.execute("SELECT album_id from album_artists\
-                                  WHERE artist_id=?\
-                                  LIMIT 1", (artist_id,))
-            v = result.fetchone()
-            # Check tracks
-            if not v:
-                result = sql.execute("SELECT track_id from track_artists\
-                                     WHERE artist_id=?\
-                                     LIMIT 1", (artist_id,))
-                v = result.fetchone()
-                # Artist with no relation, remove
-                if not v:
-                    cleaned = True
-                    sql.execute("DELETE FROM artists WHERE rowid=?",
-                                (artist_id,))
-            return cleaned
+            sql.execute("DELETE FROM artists WHERE artists.rowid NOT IN (\
+                            SELECT album_artists.artist_id\
+                            FROM album_artists) AND artists.rowid NOT IN (\
+                                SELECT track_artists.artist_id\
+                                FROM track_artists)")
