@@ -16,7 +16,7 @@ import itertools
 
 from lollypop.sqlcursor import SqlCursor
 from lollypop.define import App, OrderBy
-from lollypop.utils import noaccents, remove_static_genres
+from lollypop.utils import noaccents
 
 
 class TracksDatabase:
@@ -125,9 +125,9 @@ class TracksDatabase:
         """
         with SqlCursor(App().db) as sql:
             result = sql.execute("SELECT rowid\
-                                  FROM tracks WHERE name=?\
-                                  COLLATE NOCASE COLLATE LOCALIZED",
-                                 (name,))
+                                  FROM tracks WHERE noaccents(name)=?\
+                                  COLLATE NOCASE",
+                                 (noaccents(name),))
             return list(itertools.chain(*result))
 
     def get_id_by_uri(self, uri):
@@ -160,7 +160,7 @@ class TracksDatabase:
                 return v[0]
             return None
 
-    def get_id_by(self, name, album_id, artist_ids):
+    def get_id_by(self, name, album_id, artist_ids=[]):
         """
             Return track id for name/album/artists
             @param name as str
@@ -168,18 +168,24 @@ class TracksDatabase:
             @return track id as int
         """
         with SqlCursor(App().db) as sql:
-            filters = (name, album_id) + tuple(artist_ids)
-            request = "SELECT tracks.rowid FROM tracks\
-                       WHERE name = ? COLLATE NOCASE\
-                       AND album_id = ?\
-                       AND EXISTS (\
-                            SELECT rowid\
-                            FROM track_artists\
-                            WHERE track_artists.track_id=tracks.rowid\
-                            AND ("
-            for artist_id in artist_ids:
-                request += " track_artists.artist_id=? OR"
-            request += " 1=0))"
+            if artist_ids:
+                filters = (name, album_id) + tuple(artist_ids)
+                request = "SELECT tracks.rowid FROM tracks\
+                           WHERE name = ? COLLATE NOCASE\
+                           AND album_id = ?\
+                           AND EXISTS (\
+                                SELECT rowid\
+                                FROM track_artists\
+                                WHERE track_artists.track_id=tracks.rowid\
+                                AND ("
+                for artist_id in artist_ids:
+                    request += " track_artists.artist_id=? OR"
+                request += " 1=0))"
+            else:
+                filters = (name, album_id)
+                request = "SELECT tracks.rowid FROM tracks\
+                           WHERE name = ? COLLATE NOCASE\
+                           AND album_id = ?"
             result = sql.execute(request, filters)
             v = result.fetchone()
             if v is not None:
@@ -311,7 +317,7 @@ class TracksDatabase:
 
     def set_uri(self, track_id, uri):
         """
-            Set track uri, reset duration if web uri
+            Set track uri
             @param Track id as int
             @param uri as string
         """
@@ -319,8 +325,6 @@ class TracksDatabase:
             sql.execute("UPDATE tracks SET uri=?\
                          WHERE rowid=?",
                         (uri, track_id))
-            if uri.startswith("http") or uri.startswith("https"):
-                self.set_duration(track_id, 0)
 
     def set_rate(self, track_id, rate):
         """
@@ -432,7 +436,6 @@ class TracksDatabase:
             @return albums ids as [int]
             @param ignore as bool
         """
-        genre_ids = remove_static_genres(genre_ids)
         orderby = App().settings.get_enum("orderby")
         if artist_ids or orderby == OrderBy.ARTIST:
             order = " ORDER BY artists.sortname\
@@ -533,15 +536,12 @@ class TracksDatabase:
                 mtimes.update((row,))
             return mtimes
 
-    def get_non_persistent(self):
+    def del_non_persistent(self):
         """
-            Return non persistent tracks
-            @return track ids as [int]
+            Delete non persistent tracks
         """
-        with SqlCursor(App().db) as sql:
-            result = sql.execute("SELECT rowid FROM tracks\
-                                  WHERE mtime=0")
-            return list(itertools.chain(*result))
+        with SqlCursor(App().db, True) as sql:
+            sql.execute("DELETE FROM tracks WHERE mtime=0")
 
     def get_uris(self, uris_concerned=None):
         """
@@ -555,10 +555,11 @@ class TracksDatabase:
                 for uri in uris_concerned:
                     result = sql.execute("SELECT uri\
                                           FROM tracks\
-                                          WHERE uri LIKE ?", (uri + "%",))
+                                          WHERE uri LIKE ? AND\
+                                          mtime!=0", (uri + "%",))
                     uris += list(itertools.chain(*result))
             else:
-                result = sql.execute("SELECT uri FROM tracks")
+                result = sql.execute("SELECT uri FROM tracks WHERE mtime>0")
                 uris = list(itertools.chain(*result))
             return uris
 
@@ -601,6 +602,16 @@ class TracksDatabase:
                          SET duration=?\
                          WHERE rowid=?", (duration, track_id,))
 
+    def set_mtime(self, track_id, mtime):
+        """
+            Set track_mtime
+            @param track_id as int
+            @param mtime as int
+        """
+        with SqlCursor(App().db, True) as sql:
+            sql.execute("UPDATE tracks SET mtime=? WHERE rowid=?",
+                        (mtime, track_id))
+
     def is_empty(self):
         """
             Return True if no tracks in db
@@ -653,7 +664,7 @@ class TracksDatabase:
         """
         with SqlCursor(App().db) as sql:
             result = sql.execute("SELECT rowid FROM tracks\
-                                  WHERE popularity!=0\
+                                  WHERE popularity!=0 AND mtime != 0\
                                   ORDER BY popularity DESC LIMIT ?",
                                  (limit,))
             return list(itertools.chain(*result))
@@ -665,7 +676,7 @@ class TracksDatabase:
         """
         with SqlCursor(App().db) as sql:
             result = sql.execute("SELECT popularity\
-                                  FROM tracks\
+                                  FROM tracks WHERE mtime != 0\
                                   ORDER BY POPULARITY DESC LIMIT 1")
             v = result.fetchone()
             if v is not None:
@@ -681,6 +692,7 @@ class TracksDatabase:
             result = sql.execute("SELECT AVG(popularity)\
                                   FROM (SELECT popularity\
                                         FROM tracks\
+                                        WHERE mtime != 0\
                                         ORDER BY POPULARITY DESC LIMIT 100)")
             v = result.fetchone()
             if v and v[0] > 5:
@@ -723,7 +735,7 @@ class TracksDatabase:
         with SqlCursor(App().db) as sql:
             result = sql.execute("SELECT tracks.rowid\
                                   FROM tracks\
-                                  WHERE ltime=0\
+                                  WHERE ltime=0 AND mtime!=0\
                                   ORDER BY random() LIMIT 100")
             return list(itertools.chain(*result))
 
@@ -735,7 +747,7 @@ class TracksDatabase:
         with SqlCursor(App().db) as sql:
             result = sql.execute("SELECT tracks.rowid\
                                   FROM tracks\
-                                  WHERE ltime!=0\
+                                  WHERE ltime!=0 AND mtime!=0\
                                   ORDER BY ltime DESC LIMIT 100")
             return list(itertools.chain(*result))
 
@@ -746,7 +758,7 @@ class TracksDatabase:
         """
         with SqlCursor(App().db) as sql:
             result = sql.execute("SELECT tracks.rowid\
-                                  FROM tracks\
+                                  FROM tracks WHERE mtime != 0\
                                   ORDER BY random() LIMIT 100")
             return list(itertools.chain(*result))
 
@@ -814,7 +826,7 @@ class TracksDatabase:
 
     def get_mtime(self, track_id):
         """
-            Get modification time, if genre_ids empty, only local tracks
+            Get modification time
             @param track_id as int
             @return modification time as int
         """
@@ -850,7 +862,7 @@ class TracksDatabase:
                 return v[0]
             return 0
 
-    def clean(self, track_id):
+    def clean(self):
         """
             Clean database for track id
             @param track_id as int
@@ -858,14 +870,16 @@ class TracksDatabase:
         """
         with SqlCursor(App().db, True) as sql:
             sql.execute("DELETE FROM track_artists\
-                         WHERE track_id = ?", (track_id,))
+                         WHERE track_artists.track_id NOT IN (\
+                            SELECT tracks.rowid FROM tracks)")
             sql.execute("DELETE FROM track_genres\
-                         WHERE track_id = ?", (track_id,))
+                         WHERE track_genres.track_id NOT IN (\
+                            SELECT tracks.rowid FROM tracks)")
 
     def search(self, searched):
         """
             Search for tracks looking like searched
-            @param searched as string
+            @param searched as str
             @return [int]
         """
         no_accents = noaccents(searched)
@@ -874,10 +888,10 @@ class TracksDatabase:
             for filter in [(no_accents + "%",),
                            ("%" + no_accents,),
                            ("%" + no_accents + "%",)]:
-                result = sql.execute("SELECT tracks.rowid\
-                                      FROM tracks\
-                                      WHERE noaccents(name) LIKE ? LIMIT 25",
-                                     filter)
+                request = "SELECT tracks.rowid FROM tracks\
+                           WHERE noaccents(name) LIKE ?\
+                           AND tracks.mtime!=0 LIMIT 25"
+                result = sql.execute(request, filter)
                 items += list(itertools.chain(*result))
             return items
 
@@ -888,17 +902,21 @@ class TracksDatabase:
             @param title as string
             @param sql as sqlite cursor
             @return track id as int
-            @thread safe
         """
+        artist = noaccents(artist.lower())
         track_ids = self.get_ids_for_name(title)
         for track_id in track_ids:
             album_id = App().tracks.get_album_id(track_id)
             artist_ids = set(App().albums.get_artist_ids(album_id)) &\
                 set(App().tracks.get_artist_ids(track_id))
             for artist_id in artist_ids:
-                if artist == App().artists.get_name(artist_id):
+                db_artist = noaccents(
+                    App().artists.get_name(artist_id).lower())
+                if artist.find(db_artist) != -1 or\
+                        db_artist.find(artist) != -1:
                     return track_id
-            if ", ".join(App().tracks.get_artists(track_id)) == artist:
+            artists = ", ".join(App().tracks.get_artists(track_id)).lower()
+            if noaccents(artists) == artist:
                 return track_id
         return None
 
