@@ -28,11 +28,10 @@ MARGIN = 15
 MARGIN_SMALL = 5
 
 
-# Represent what to do on next track
-class NextContext:
-    NONE = 0             # Continue playback
-    REPEAT_TRACK = 1     # Repeat current track
-    STOP = 2             # Stop after track/album/artist
+class Repeat:
+    NONE = 0
+    TRACK = 1
+    ALL = 2
 
 
 class GstPlayFlags:
@@ -41,6 +40,17 @@ class GstPlayFlags:
     GST_PLAY_FLAG_TEXT = 1 << 3   # We want subtitle output
 
 
+class ArtHelperEffect:
+    NONE = 1 << 1
+    ROUNDED = 1 << 2
+    BLUR = 1 << 3
+    BLUR_HARD = 1 << 4
+    RESIZE = 1 << 5
+    FALLBACK = 1 << 6
+    SAVE = 1 << 7
+    DARKER = 1 << 8
+
+
 class ViewType:
     DEFAULT = 1 << 0
     TWO_COLUMNS = 1 << 1
@@ -57,6 +67,14 @@ class ViewType:
     FULLSCREEN = 1 << 12
 
 
+class IndicatorType:
+    NONE = 1 << 0
+    PLAY = 1 << 1
+    LOVED = 1 << 2
+    SKIP = 1 << 3
+    LOADING = 1 << 4
+
+
 class ArtSize:
     NONE = 0
     SMALL = 33
@@ -147,6 +165,7 @@ class Type:
     EQUALIZER = -19
     GENRES = -20
     ALBUM = -21
+    WEB = -22
     ALL = -100
     CURRENT = -101
     USB_DISKS = -200
@@ -155,13 +174,19 @@ class Type:
     COMPILATIONS = -2001
 
 
+LATIN1_ENCODING = b"\x00"
+"""Byte code for latin1"""
+UTF_16_ENCODING = b"\x01"
+"""Byte code for UTF-16"""
+UTF_16BE_ENCODING = b"\x02"
+"""Byte code for UTF-16 (big endian)"""
+UTF_8_ENCODING = b"\x03"
+"""Byte code for UTF-8 (Not supported in ID3 versions < 2.4)"""
+
+
 SPOTIFY_CLIENT_ID = "0b144843878a46b2b12e0958c342c3ac"
 SPOTIFY_SECRET = "265ab8e057684f1b9e69e0c58f4881c1"
 
-ENCODING = ["utf_8",
-            "iso8859_1",
-            "utf_16",
-            "utf_16_be"]
 
 STATIC_ALBUM_NAME = {
     Type.POPULARS: "Popular albums",
