@@ -13,9 +13,11 @@
 
 from gi.repository import GLib
 
+from urllib.parse import urlparse
 from lollypop.radios import Radios
 from lollypop.logger import Logger
 from lollypop.define import App, Type
+from lollypop.utils import remove_static_genres
 
 
 class Base:
@@ -55,6 +57,23 @@ class Base:
             else:
                 return attr_value
 
+    def reset(self, attr):
+        """
+            Reset attr
+            @param attr as str
+        """
+        attr_name = "_" + attr
+        attr_value = getattr(self.db, "get_" + attr)(self.id)
+        setattr(self, attr_name, attr_value)
+
+    @property
+    def is_in_user_collection(self):
+        """
+            True if track is in user collection
+            @return bool
+        """
+        return self.mtime > 0
+
     def get_popularity(self):
         """
             Get popularity
@@ -125,9 +144,10 @@ class Base:
         if self.id == Type.RADIOS:
             radios = Radios()
             radios.set_rate(self._radio_id, rate)
+            App().player.emit("rate-changed", self._radio_id, rate)
         else:
             self.db.set_rate(self.id, rate)
-            App().player.emit("rate-changed", (self.id, rate))
+            App().player.emit("rate-changed", self.id, rate)
 
 
 class Disc:
@@ -217,7 +237,7 @@ class Album(Base):
                 "uri": "",
                 "tracks_count": 1,
                 "duration": 0,
-                "mtime": 0,
+                "mtime": 1,
                 "synced": False,
                 "loved": False}
 
@@ -231,7 +251,7 @@ class Album(Base):
         """
         Base.__init__(self, App().albums)
         self.id = album_id
-        self.genre_ids = genre_ids
+        self.genre_ids = remove_static_genres(genre_ids)
         self._tracks = []
         self._discs = []
         self.__disallow_ignored_tracks = disallow_ignored_tracks
@@ -320,7 +340,7 @@ class Album(Base):
         """
         if self.id >= 0:
             App().albums.set_uri(self.id, uri)
-            self.uri = uri
+        self.uri = uri
 
     def get_track(self, track_id):
         """
@@ -333,6 +353,22 @@ class Album(Base):
                 return track
         return Track()
 
+    def save(self, save):
+        """
+            Save album to collection
+            @param save as bool
+        """
+        if save:
+            App().albums.set_mtime(self.id, -1)
+        else:
+            App().albums.set_mtime(self.id, 0)
+        for track in self.tracks:
+            track.save(save)
+        self.reset("mtime")
+        for artist_id in self.artist_ids:
+            App().scanner.emit("artist-updated", artist_id, save)
+        App().scanner.emit("album-updated", self.id, save)
+
     @property
     def title(self):
         """
@@ -409,7 +445,7 @@ class Track(Base):
                 "number": 0,
                 "year": None,
                 "timestamp": None,
-                "mtime": 0,
+                "mtime": 1,
                 "loved": False,
                 "mb_track_id": None}
 
@@ -445,6 +481,24 @@ class Track(Base):
         """
         self._uri = uri
 
+    def set_radio(self, name, uri):
+        """
+            Set radio for non DB radios (Tunein)
+            @param name as string
+            @param uri as string
+        """
+        from lollypop.radios import Radios
+        radios = Radios()
+        self.id = Type.RADIOS
+        self._radio_id = radios.get_id(name)
+        self._radio_name = name
+        self._uri = uri
+        # Generate a tmp album id, needed by InfoController
+        album_id = 0
+        for i in list(map(ord, name)):
+            album_id += i
+        self.album.id = album_id
+
     def set_radio_id(self, radio_id):
         """
             Set radio id
@@ -452,26 +506,9 @@ class Track(Base):
         """
         from lollypop.radios import Radios
         radios = Radios()
-        self.id = Type.RADIOS
-        self._radio_id = radio_id
-        self.album.id = radio_id
-        self._radio_name = radios.get_name(radio_id)
-        self._uri = radios.get_uri(radio_id)
-
-    def set_radio(self, name, uri):
-        """
-            Set radio for non DB radios (Tunein)
-            @param name as string
-            @param uri as string
-        """
-        self.id = Type.RADIOS
-        # Generate a tmp album id, needed by InfoController
-        album_id = 0
-        for i in list(map(ord, name)):
-            album_id += i
-        self.album.id = album_id
-        self._radio_name = name
-        self._uri = uri
+        name = radios.get_name(radio_id)
+        uri = radios.get_uri(radio_id)
+        self.set_radio(name, uri)
 
     def set_number(self, number):
         """
@@ -489,6 +526,17 @@ class Track(Base):
             App().tracks.set_loved(self.id, loved)
             self.loved = loved
 
+    def save(self, save):
+        """
+            Save track to collection
+            @param save as bool
+        """
+        if save:
+            App().tracks.set_mtime(self.id, -1)
+        else:
+            App().tracks.set_mtime(self.id, 0)
+        self.reset("mtime")
+
     def get_featuring_artist_ids(self, album_artist_ids):
         """
             Get featuring artist ids
@@ -497,6 +545,23 @@ class Track(Base):
         artist_ids = self.db.get_artist_ids(self.id)
         return list(set(artist_ids) - set(album_artist_ids))
 
+    @property
+    def is_web(self):
+        """
+            True if track is a web track
+            @return bool
+        """
+        return self.is_http or self.uri.startswith("web:")
+
+    @property
+    def is_http(self):
+        """
+            True if track is a http track
+            @return bool
+        """
+        parsed = urlparse(self.uri)
+        return parsed.scheme in ["http", "https"]
+
     @property
     def position(self):
         """
