@@ -370,7 +370,10 @@ class BinPlayer(BasePlayer):
                 App().scanner.stop()
                 self.stop()
             elif App().notify is not None:
-                App().notify.send(message.parse_error()[0].message)
+                parsed = message.parse_error()
+                for item in parsed:
+                    if item is not None:
+                        App().notify.send(item.message)
                 self.stop()
 
     def _on_bus_eos(self, bus, message):
@@ -381,8 +384,6 @@ class BinPlayer(BasePlayer):
         self.emit("loading-changed", False)
         Logger.debug("Player::__on_bus_eos(): %s" % self._current_track.uri)
         if self._playbin.get_bus() == bus:
-            if App().notify is not None:
-                App().notify.send(message.parse_error()[0].message)
             self.stop()
 
     def _on_stream_about_to_finish(self, playbin):
@@ -500,10 +501,9 @@ class BinPlayer(BasePlayer):
             @param next as bool
         """
         # No cossfading if we need to stop
-        next_ok = next and self._next_track.id is not None
-        prev_ok = not next and self._prev_track.id is not None
-        if track is None and not next_ok or not prev_ok:
-            self._crossfading = False
+        next_ok = not next or self._next_track.id is not None
+        prev_ok = next or self._prev_track.id is not None
+        if not next_ok or not prev_ok:
             return
 
         if track is None:
