@@ -16,7 +16,7 @@ from gettext import gettext as _
 
 from lollypop.widgets_rating import RatingWidget
 from lollypop.widgets_loved import LovedWidget
-from lollypop.define import App
+from lollypop.define import App, ViewType
 from lollypop.objects import Track, Album
 from lollypop.widgets_utils import Popover
 from lollypop.logger import Logger
@@ -41,26 +41,44 @@ class ArtistMenu(BaseMenu):
         Contextual menu for artist
     """
 
-    def __init__(self, object):
+    def __init__(self, object, view_type):
         """
             Init playlists menu
             @param object as Album/Track
+            @param view_type as ViewType
         """
         BaseMenu.__init__(self, object)
-        self.__set_artists_actions()
+        self.__set_artists_actions(view_type)
 
 #######################
 # PRIVATE             #
 #######################
-    def __set_artists_actions(self):
+    def __set_artists_actions(self, view_type):
         """
-            Set queue actions
+            Set artist actions
+            @param view_type as ViewType
         """
-        go_artist_action = Gio.SimpleAction(name="go_artist_action")
-        App().add_action(go_artist_action)
-        go_artist_action.connect("activate",
-                                 self.__go_to_artists)
-        self.append(_("Show albums from artist"), "app.go_artist_action")
+        if view_type & ViewType.ALBUM:
+            go_artist_action = Gio.SimpleAction(name="go_artist_action")
+            App().add_action(go_artist_action)
+            go_artist_action.connect("activate",
+                                     self.__go_to_artists)
+            self.append(_("Available albums"), "app.go_artist_action")
+        search_artist_action = Gio.SimpleAction(name="search_artist_action")
+        App().add_action(search_artist_action)
+        search_artist_action.connect("activate",
+                                     self.__search_artist)
+        self.append(_("Other albums"), "app.search_artist_action")
+
+    def __search_artist(self, action, variant):
+        """
+            Search albums from artist
+            @param Gio.SimpleAction
+            @param GLib.Variant
+        """
+        artist_name = App().artists.get_name(self._object.artist_ids[0])
+        target = "web://%s" % artist_name
+        App().lookup_action("search").activate(GLib.Variant("s", target))
 
     def __go_to_artists(self, action, variant):
         """
@@ -68,11 +86,7 @@ class ArtistMenu(BaseMenu):
             @param Gio.SimpleAction
             @param GLib.Variant
         """
-        if App().settings.get_value("show-sidebar"):
-            App().window.container.show_artists_albums(
-                 self._object.artist_ids)
-        else:
-            App().window.container.show_view(self._object.artist_ids[0])
+        App().window.container.show_artist_view(self._object.artist_ids)
 
 
 class PlaybackMenu(BaseMenu):
@@ -177,6 +191,8 @@ class PlaybackMenu(BaseMenu):
                     track = album.tracks[index]
                     album.remove_track(track)
                     break
+        App().player.set_next()
+        App().player.set_prev()
 
     def __append_to_queue(self, action, variant):
         """
@@ -336,7 +352,7 @@ class ToolbarMenu(BaseMenu):
             playlist_menu = PlaylistsMenu(track)
             self.insert_section(1, _("Playlists"), playlist_menu)
         self.insert_section(2, _("Artist"),
-                            ArtistMenu(track))
+                            ArtistMenu(track, ViewType.ALBUM))
 
 #######################
 # PRIVATE             #
@@ -366,21 +382,47 @@ class EditMenu(BaseMenu):
         else:
             obj = Track(object.id)
         BaseMenu.__init__(self, obj)
-        if App().art.tag_editor:
-            self.__set_edit_actions()
+        if isinstance(object, Album):
+            self.__set_save_action()
+        if object.is_in_user_collection and App().art.tag_editor:
+            self.__set_edit_action()
 
 #######################
 # PRIVATE             #
 #######################
-    def __set_edit_actions(self):
+    def __set_save_action(self):
         """
-            Set edit actions
+            Set save action
+        """
+        if self._object.mtime == 0:
+            save_action = Gio.SimpleAction(name="save_album_action")
+            App().add_action(save_action)
+            save_action.connect("activate", self.__save_to_collection, True)
+            self.append(_("Save in collection"), "app.save_album_action")
+        elif self._object.mtime == -1:
+            save_action = Gio.SimpleAction(name="remove_album_action")
+            App().add_action(save_action)
+            save_action.connect("activate", self.__save_to_collection, False)
+            self.append(_("Remove from collection"), "app.remove_album_action")
+
+    def __set_edit_action(self):
+        """
+            Set edit action
         """
         edit_tag_action = Gio.SimpleAction(name="edit_tag_action")
         App().add_action(edit_tag_action)
         edit_tag_action.connect("activate", self.__edit_tag)
         self.append(_("Modify information"), "app.edit_tag_action")
 
+    def __save_to_collection(self, action, variant, save):
+        """
+            Save album to collection
+            @param Gio.SimpleAction
+            @param GLib.Variant
+            @param save as bool
+        """
+        self._object.save(save)
+
     def __edit_tag(self, action, variant):
         """
             Run tag editor
@@ -409,18 +451,18 @@ class AlbumMenu(Gio.Menu):
         Contextual menu for album
     """
 
-    def __init__(self, album, show_artist=False):
+    def __init__(self, album, view_type):
         """
             Init menu model
             @param album as Album
-            @param show artist menu as bool
+            @param view_type as ViewType
         """
         Gio.Menu.__init__(self)
-        if show_artist:
-            self.insert_section(0, _("Artist"),
-                                ArtistMenu(album))
-        self.insert_section(2, _("Playlists"),
-                            PlaylistsMenu(album))
+        self.insert_section(0, _("Artist"),
+                            ArtistMenu(album, view_type))
+        if album.mtime != 0:
+            self.insert_section(2, _("Playlists"),
+                                PlaylistsMenu(album))
         self.insert_section(3, _("Edit"),
                             EditMenu(album))
 
@@ -437,13 +479,14 @@ class TrackMenu(Gio.Menu):
             @param show artist menu as bool
         """
         Gio.Menu.__init__(self)
-        if show_artist:
+        if show_artist and track.mtime != 0:
             self.insert_section(0, _("Artist"),
-                                ArtistMenu(track))
+                                ArtistMenu(track, ViewType.ALBUM))
         self.insert_section(1, _("Playback"),
                             PlaybackMenu(track))
-        self.insert_section(2, _("Playlists"),
-                            PlaylistsMenu(track))
+        if track.mtime != 0:
+            self.insert_section(2, _("Playlists"),
+                                PlaylistsMenu(track))
         self.insert_section(3, _("Edit"),
                             EditMenu(track))
 
@@ -497,6 +540,9 @@ class TrackMenuPopover(Popover):
         if menu is not None:
             self.bind_model(menu, None)
 
+        if track.mtime == 0:
+            return
+
         if track.year is not None:
             year_label = Gtk.Label.new()
             year_label.set_text(str(track.year))
@@ -540,16 +586,34 @@ class TrackMenuPopover(Popover):
             hgrid.add(year_label)
         hgrid.show()
 
+        if track.mtime in [-1, 0]:
+            edit = Gtk.Entry()
+            edit.set_margin_top(5)
+            edit.set_margin_start(5)
+            edit.set_margin_end(5)
+            edit.set_margin_bottom(5)
+            edit.set_property("hexpand", True)
+            edit.set_text(track.uri)
+            edit.connect("changed", self.__on_edit_changed, track)
+            edit.show()
+            grid.add(edit)
+
         grid.add(hgrid)
         self.add(stack)
 
 #######################
 # PRIVATE             #
 #######################
-    def __on_edit_changed(self, edit, track_id):
+    def __on_edit_changed(self, edit, track):
         """
             Update track uri
             @param edit as Gtk.Edit
-            @param track id as int
+            @param track as Track
         """
-        App().tracks.set_uri(track_id, edit.get_text())
+        from urllib.parse import urlparse
+        text = edit.get_text()
+        parsed = urlparse(text)
+        if parsed.scheme not in ["http", "https", "web"]:
+            text = "web://null"
+        App().tracks.set_uri(track.id, text)
+        track.reset("uri")
