@@ -67,6 +67,9 @@ class ViewsMenuPopover(Popover):
             lists = ShownPlaylists.get(True)
             wanted = App().settings.get_value("shown-playlists")
         else:
+            mask |= SelectionListMask.COMPILATIONS
+            if mask & SelectionListMask.LIST_ONE:
+                mask |= SelectionListMask.LIST_DEVICE
             lists = ShownLists.get(mask, True)
             wanted = App().settings.get_value("shown-album-lists")
         for item in lists:
@@ -117,7 +120,7 @@ class ViewsMenuPopover(Popover):
         else:
             self.__widget.remove_value(rowid)
             if self.__mask & SelectionListMask.LIST_ONE:
-                ids = App().settings.get_value("startup-one-ids")
+                ids = list(App().settings.get_value("startup-one-ids"))
                 if rowid in ids:
                     ids.remove(rowid)
                 App().settings.set_value("startup-one-ids",
