@@ -10,12 +10,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib, Pango
+from gi.repository import Gtk, Gio, GLib, Pango, GObject
 
 from lollypop.define import App, ArtSize
 from lollypop.utils import get_network_available
-from lollypop.helper_spotify import SpotifyHelper
 from lollypop.widgets_utils import Popover
+from lollypop.information_store import InformationStore
 from lollypop.logger import Logger
 
 
@@ -24,23 +24,28 @@ class ArtistRow(Gtk.ListBoxRow):
         An artist row
     """
 
-    def __init__(self, artist_name):
+    def __init__(self, artist_name, cover_uri, cancellable):
         """
             Init row
             @param artist_name as str
+            @param cover_uri as str
+            @param cancellable as Gio.Cancellable
         """
         Gtk.ListBoxRow.__init__(self)
         self.__artist_name = artist_name
+        self.__cover_uri = cover_uri
+        self.__cancellable = cancellable
         grid = Gtk.Grid()
         grid.set_column_spacing(5)
         label = Gtk.Label.new(artist_name)
         label.set_property("halign", Gtk.Align.START)
         label.set_ellipsize(Pango.EllipsizeMode.END)
         self.__artwork = Gtk.Image.new()
-        self.__artwork.set_size_request(ArtSize.MEDIUM, ArtSize.MEDIUM)
+        self.__artwork.set_size_request(ArtSize.ARTIST_SMALL,
+                                        ArtSize.ARTIST_SMALL)
         App().art_helper.set_artist_artwork(artist_name,
-                                            ArtSize.MEDIUM,
-                                            ArtSize.MEDIUM,
+                                            ArtSize.ARTIST_SMALL,
+                                            ArtSize.ARTIST_SMALL,
                                             self.get_scale_factor(),
                                             self.__on_artist_artwork)
         grid.add(self.__artwork)
@@ -59,17 +64,47 @@ class ArtistRow(Gtk.ListBoxRow):
 #######################
 # PRIVATE             #
 #######################
+    def __on_uri_content(self, uri, status, data):
+        """
+            Save artwork to cache and set artist artwork
+            @param uri as str
+            @param status as bool
+            @param data as bytes
+        """
+        try:
+            if not status:
+                return
+            self.__cover_data = data
+            scale_factor = self.get_scale_factor()
+            InformationStore.add_artist_artwork(self.__artist_name,
+                                                data, True)
+            App().art_helper.set_artist_artwork(self.__artist_name,
+                                                ArtSize.ARTIST_SMALL,
+                                                ArtSize.ARTIST_SMALL,
+                                                scale_factor,
+                                                self.__on_artist_artwork,)
+        except Exception as e:
+            Logger.error("ArtistRow::__on_uri_content(): %s", e)
+
     def __on_artist_artwork(self, surface):
         """
             Set artist artwork
             @param surface as cairo.Surface
         """
         if surface is None:
+            # Last chance to get a cover
+            if self.__cover_uri is not None:
+                App().task_helper.load_uri_content(self.__cover_uri,
+                                                   self.__cancellable,
+                                                   self.__on_uri_content)
+                self.__cover_uri = None
             self.__artwork.get_style_context().add_class("artwork-icon")
             self.__artwork.set_from_icon_name("avatar-default-symbolic",
                                               Gtk.IconSize.INVALID)
-            self.__artwork.set_pixel_size(ArtSize.MEDIUM)
+            # artwork-icon padding is 5px
+            self.__artwork.set_pixel_size(ArtSize.ARTIST_SMALL - 20)
         else:
+            self.__artwork.get_style_context().remove_class("artwork-icon")
             self.__artwork.set_from_surface(surface)
 
 
@@ -83,10 +118,15 @@ class SimilarsPopover(Popover):
             Init popover
         """
         Popover.__init__(self)
+        self.__lastfm_signal_id = None
+        self.__spotify_signal_id = None
         builder = Gtk.Builder()
         builder.add_from_resource("/org/gnome/Lollypop/SimilarsPopover.ui")
+        self.__show_all = GLib.find_program_in_path("youtube-dl") is not None
         self.__added = []
+        self.__cancellable = Gio.Cancellable()
         self.connect("map", self.__on_map)
+        self.connect("unmap", self.__on_unmap)
         self.__stack = builder.get_object("stack")
         self.__spinner = builder.get_object("spinner")
         self.__spinner.start()
@@ -106,82 +146,98 @@ class SimilarsPopover(Popover):
             @param artist ids as int
         """
         if get_network_available():
+            self.__providers = 1
             artists = []
             for artist_id in artist_ids:
                 artist_name = App().artists.get_name(artist_id)
                 artists.append(artist_name)
-                SpotifyHelper.get_artist_id(artist_name,
+                App().spotify.get_artist_id(artist_name,
                                             self.__on_get_artist_id)
-        if App().lastfm is not None:
-            App().task_helper.run(self.__get_lastfm_similars, artists,
-                                  callback=(self.__populate,))
+            if App().lastfm is not None:
+                self.__providers = 2
+                App().task_helper.run(self.__search_lastfm_similars, artists)
 
 #######################
 # PRIVATE             #
 #######################
-    def __get_lastfm_similars(self, artists):
+    def __search_lastfm_similars(self, artists):
         """
-            Get similars artists from lastfm
+            Search similars artists from lastfm
             @param artists as [str]
-            @return [str]
+            @param scale_factor as int
         """
-        similars = []
         for artist in artists:
-            similars += App().lastfm.get_similars(artist)
-        Logger.info("SimilarsPopover::Last.fm: %s" % similars)
-        return similars
-
-    def __populate(self, artists):
-        """
-            Populate view with artists
-            @param artists as [str]
-        """
-        if artists:
-            artist = artists.pop(0)
-            if artist in self.__added:
-                GLib.idle_add(self.__populate, artists)
-                return
-            self.__added.append(artist)
-            artist_id = App().artists.get_id(artist)
-            # We want real artist name (with case)
-            artist_name = App().artists.get_name(artist_id)
-            if artist_id is not None:
-                albums = App().artists.get_albums([artist_id])
-                if albums:
-                    row = ArtistRow(artist_name)
-                    row.show()
-                    self.__listbox.add(row)
-            GLib.idle_add(self.__populate, artists)
-        else:
-            self.__spinner.stop()
-            if self.__listbox.get_children():
-                self.__stack.set_visible_child(self.__listbox)
-            else:
-                self.__stack.set_visible_child_name("no-result")
+            if not self.__cancellable.is_cancelled():
+                App().lastfm.search_similar_artists(artist,
+                                                    self.__cancellable)
 
     def __on_get_artist_id(self, artist_id):
         """
             Get similars
             @param artist_id as str
         """
-        SpotifyHelper.get_similar_artists(artist_id,
-                                          self.__on_get_similars)
+        if artist_id is None:
+            self.__stack.set_visible_child_name("no-result")
+            self.__spinner.stop()
+        App().task_helper.run(App().spotify.search_similar_artists, artist_id,
+                              self.__cancellable)
 
-    def __on_get_similars(self, artists):
+    def __on_new_artist(self, provider, artist, cover_uri):
         """
-            Add artists
-            @param artists as str
+            Add artist to view
+            @param provider as Spotify/LastFM
+            @param artist as str
         """
-        Logger.info("SimilarsPopover::Spotify: %s" % artists)
-        self.__populate(artists)
+        if artist is None:
+            self.__providers -= 1
+            if self.__providers == 0:
+                self.__stack.set_visible_child_name("no-result")
+                self.__spinner.stop()
+            return
+        if artist in self.__added:
+            return
+        self.__added.append(artist)
+        artist_id = App().artists.get_id(artist)
+        row = None
+        if artist_id is not None:
+            # We want real artist name (with case)
+            artist_name = App().artists.get_name(artist_id)
+            albums = App().artists.get_albums([artist_id])
+            if albums:
+                row = ArtistRow(artist_name, None, self.__cancellable)
+        elif self.__show_all:
+            row = ArtistRow(artist, cover_uri, self.__cancellable)
+        if row is not None:
+            row.show()
+            self.__listbox.add(row)
+        self.__stack.set_visible_child(self.__listbox)
 
     def __on_map(self, widget):
         """
             Resize widget on map
             @param widget as Gtk.Widget
         """
+        if App().lastfm is not None:
+            self.__lastfm_signal_id = GObject.Object.connect(
+                App().lastfm, "new-artist", self.__on_new_artist)
+        self.__spotify_signal_id = App().spotify.connect(
+                "new-artist", self.__on_new_artist)
         self.set_size_request(300, 400)
 
+    def __on_unmap(self, widget):
+        """
+            Cancel loading
+            @param widget as Gtk.Widget
+        """
+        if App().lastfm is not None:
+            if self.__lastfm_signal_id is not None:
+                App().lastfm.disconnect(self.__lastfm_signal_id)
+                self.__lastfm_signal_id = None
+        if self.__spotify_signal_id is not None:
+            App().spotify.disconnect(self.__spotify_signal_id)
+            self.__spotify_signal_id = None
+        self.__cancellable.cancel()
+
     def __on_row_activated(self, widget, row):
         """
             Play searched item when selected
@@ -191,9 +247,8 @@ class SimilarsPopover(Popover):
         self.popdown()
         artist_name = row.artist_name
         artist_id = App().artists.get_id(artist_name)
-        if App().settings.get_value("show-sidebar") and\
-                not App().window.is_adaptive:
-            GLib.idle_add(App().window.container.show_artists_albums,
-                          [artist_id])
+        if artist_id is None:
+            target = "web://%s" % artist_name
         else:
-            GLib.idle_add(App().window.container.show_view, artist_id)
+            target = "local://%s" % artist_name
+        App().lookup_action("search").activate(GLib.Variant("s", target))
