@@ -16,9 +16,8 @@ from gettext import gettext as _
 
 from lollypop.logger import Logger
 from lollypop.widgets_utils import Popover
-from lollypop.helper_art import ArtHelperEffect
 from lollypop.controller_information import InformationController
-from lollypop.define import App, Type
+from lollypop.define import App, Type, ArtHelperEffect
 
 
 class ToolbarInfo(Gtk.Bin, InformationController):
@@ -101,7 +100,9 @@ class ToolbarInfo(Gtk.Bin, InformationController):
             player as Player
         """
         if self.get_realized():
-            InformationController.on_current_changed(self, self.art_size, None)
+            InformationController.on_current_changed(self,
+                                                     self.__art_size,
+                                                     None)
 
 #######################
 # PROTECTED           #
@@ -115,6 +116,23 @@ class ToolbarInfo(Gtk.Bin, InformationController):
         except:
             Logger.warning(_("You are using a broken cursor theme!"))
 
+    def _on_artwork(self, surface):
+        """
+            Set artwork
+            @param surface as str
+        """
+        if surface is None:
+            if App().player.current_track.id == Type.RADIOS:
+                icon_name = "audio-input-microphone-symbolic"
+            else:
+                icon_name = "folder-music-symbolic"
+            self._artwork.set_from_icon_name(icon_name,
+                                             Gtk.IconSize.BUTTON)
+            self._artwork.set_size_request(self.__art_size, self.__art_size)
+        else:
+            InformationController._on_artwork(self, surface)
+            self._artwork.set_size_request(-1, -1)
+
 #######################
 # PRIVATE             #
 #######################
@@ -125,7 +143,7 @@ class ToolbarInfo(Gtk.Bin, InformationController):
             @param album id as int
         """
         if App().player.current_track.album.id == album_id:
-            self.update_artwork(self.art_size, self.art_size)
+            self.update_artwork(self.__art_size, self.__art_size)
 
     def __update_logo(self, art, name):
         """
@@ -135,7 +153,7 @@ class ToolbarInfo(Gtk.Bin, InformationController):
         """
         if App().player.current_track.album_artist == name:
             pixbuf = App().art.get_radio_artwork(
-                name, self.art_size, self.art_size)
+                name, self.__art_size, self.__art_size)
             self._artwork.set_from_surface(pixbuf)
 
     def __popup_menu(self):
@@ -198,8 +216,7 @@ class ToolbarInfo(Gtk.Bin, InformationController):
             Calculate art size
             @param toolbar as ToolbarInfos
         """
-        art_size = self.get_allocated_height()
-        self.set_art_size(art_size)
+        self.__art_size = self.get_allocated_height()
         if App().player.current_track.id is not None:
             self.on_current_changed(App().player)
 
