@@ -95,7 +95,6 @@ class PlaylistsView(LazyLoadingView, ViewController):
                     "text-x-large")
             self.__title_label.set_property("valign", Gtk.Align.END)
             self.__duration_label.set_property("valign", Gtk.Align.START)
-            self.__widget.get_style_context().add_class("black")
             self.__banner = PlaylistBannerWidget(playlist_ids[0])
             self.__banner.show()
             self._overlay.add_overlay(self.__banner)
@@ -103,9 +102,6 @@ class PlaylistsView(LazyLoadingView, ViewController):
             self.__playlists_widget.set_margin_top(
                 self.__banner.default_height + 15)
             self.add(self._overlay)
-        if App().player.is_locked:
-            self.__play_button.set_sensitive(False)
-            self.__shuffle_button.set_sensitive(False)
         self.__title_label.set_label(
             ", ".join(App().playlists.get_names(playlist_ids)))
         self._scrolled.set_property("expand", True)
