@@ -19,7 +19,7 @@ from lollypop.define import App, Sizing, Type, ScanType
 from lollypop.toolbar import Toolbar
 from lollypop.logger import Logger
 from lollypop.adaptive import AdaptiveWindow
-from lollypop.utils import is_unity
+from lollypop.utils import is_unity, get_headerbar_buttons_width
 
 
 class Window(Gtk.ApplicationWindow, AdaptiveWindow):
@@ -42,6 +42,7 @@ class Window(Gtk.ApplicationWindow, AdaptiveWindow):
         self.__miniplayer = None
         self.__mediakeys = None
         self.__media_keys_busnames = []
+        self.__headerbar_buttons_width = get_headerbar_buttons_width()
         self.connect("map", self.__on_map)
         self.connect("unmap", self.__on_unmap)
         App().player.connect("current-changed", self.__on_current_changed)
@@ -121,7 +122,6 @@ class Window(Gtk.ApplicationWindow, AdaptiveWindow):
         """
             Setup global shortcuts
         """
-        App().set_accels_for_action("app.shortcut::locked", ["<Control>l"])
         App().set_accels_for_action("app.shortcut::filter", ["<Control>i"])
         App().set_accels_for_action("app.shortcut::volume",
                                     ["<Shift><Alt>v"])
@@ -161,6 +161,10 @@ class Window(Gtk.ApplicationWindow, AdaptiveWindow):
         App().set_accels_for_action("app.shortcut::prev", ["<Alt>p"])
         App().set_accels_for_action("app.shortcut::loved", ["<Alt>l"])
         App().set_accels_for_action("app.shortcut::reload", ["<Control>r"])
+        App().set_accels_for_action("app.shortcut::volume_up",
+                                    ["<Shift><Alt>Up"])
+        App().set_accels_for_action("app.shortcut::volume_down",
+                                    ["<Shift><Alt>Down"])
 
     def __show_miniplayer(self, show):
         """
@@ -171,13 +175,15 @@ class Window(Gtk.ApplicationWindow, AdaptiveWindow):
             miniplayer.set_vexpand(revealed)
             if revealed:
                 self.__container.hide()
-                App().window.emit("show-can-go-back", False)
+                self.emit("can-go-back-changed", False)
+                self.toolbar.end.home_button.set_sensitive(False)
             else:
                 self.__container.show()
-                App().window.emit("show-can-go-back", True)
+                self.emit("can-go-back-changed", self.can_go_back)
+                self.toolbar.end.home_button.set_sensitive(True)
         if show and self.__miniplayer is None:
             from lollypop.miniplayer import MiniPlayer
-            self.__miniplayer = MiniPlayer(self.get_size()[0])
+            self.__miniplayer = MiniPlayer()
             self.__miniplayer.connect("revealed", on_revealed)
             self.__miniplayer.set_vexpand(False)
             self.__vgrid.add(self.__miniplayer)
@@ -315,7 +321,7 @@ class Window(Gtk.ApplicationWindow, AdaptiveWindow):
             @param width as int
             @param height as int
         """
-        if width < Sizing.MONSTER:
+        if width - self.__headerbar_buttons_width < Sizing.MONSTER:
             self.__show_miniplayer(True)
         else:
             self.__show_miniplayer(False)
@@ -380,11 +386,6 @@ class Window(Gtk.ApplicationWindow, AdaptiveWindow):
         (width, height) = window.get_size()
         self.__handle_miniplayer(width, height)
         self.__toolbar.set_content_width(width)
-        if self.__miniplayer is not None:
-            if height > width:
-                self.__miniplayer.update_cover(height)
-            else:
-                self.__miniplayer.update_cover(width)
         if self.__timeout_configure:
             GLib.source_remove(self.__timeout_configure)
             self.__timeout_configure = None
@@ -457,14 +458,16 @@ class Window(Gtk.ApplicationWindow, AdaptiveWindow):
             App().player.skip_album()
         elif string == "prev":
             App().player.prev()
-        elif string == "locked":
-            App().player.lock()
         elif string == "go_back":
-            App().window.go_back()
+            self.go_back()
         elif string == "lyrics":
-            App().window.container.show_lyrics()
+            self.container.show_lyrics()
         elif string == "reload":
-            App().window.container.reload_view()
+            self.container.reload_view()
+        elif string == "volume_up":
+            App().player.set_volume(App().player.volume + 0.1)
+        elif string == "volume_down":
+            App().player.set_volume(App().player.volume - 0.1)
         elif string == "show_sidebar":
             value = App().settings.get_value("show-sidebar")
             App().settings.set_value("show-sidebar",
@@ -474,15 +477,12 @@ class Window(Gtk.ApplicationWindow, AdaptiveWindow):
             if self.container.view is not None:
                 self.container.view.enable_filter()
         elif string == "volume":
-            App().window.container.show_view(Type.EQUALIZER)
+            self.container.show_view(Type.EQUALIZER)
         elif string == "current_artist":
             if App().player.current_track.id is not None and\
                     App().player.current_track.id > 0:
                 artist_ids = App().player.current_track.album.artist_ids
-                if App().settings.get_value("show-sidebar"):
-                    self.container.show_artists_albums(artist_ids)
-                else:
-                    App().window.container.show_view(artist_ids[0])
+                self.container.show_artist_view(artist_ids)
         elif string == "loved":
             track = App().player.current_track
             if track.id is not None and track.id >= 0:
